==> haskell-binary-instances-1.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-instances
version:              1.0.1
visibility:           public
id:                   binary-instances-1.0.1-BXXUR8JzxPr2CWZ598o88k
key:                  binary-instances-1.0.1-BXXUR8JzxPr2CWZ598o88k
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  1cbaab38f45784ec2133cbc31a19a2b3
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Scientific
    Data.Binary.Instances.Tagged Data.Binary.Instances.Text
    Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/binary-instances-1.0.1
hs-libraries:         HSbinary-instances-1.0.1-BXXUR8JzxPr2CWZ598o88k
depends:
    aeson-1.5.4.1-4wEKZPgDVdkFlnmRCF3GfK base-4.14.1.0 binary-0.8.8.0
    binary-orphans-1.0.1-4Ww9aNIW64JFtPITJYqcD4
    case-insensitive-1.2.1.0-5DMNWHGVnoo4dOW265EsdJ
    hashable-1.3.0.0-1qHAALw6V3KFC8KcGIO5Ie
    scientific-0.3.6.2-GYJ9xIed9KtBuzeH6CTmVU
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2
    text-binary-0.2.1.1-Bl0n9PdHQ5w1N8gChIUmsJ
    time-compat-1.9.5-1s4PWq9TUlJB9Wxbjv0WT0
    unordered-containers-0.2.13.0-7jajDWNmlIpBHz95ShzOz6
    vector-0.12.1.2-2RftPi1Wv2O9pWjpJnOFtm
    vector-binary-instances-0.2.5.1-AWxWf0J7vFjFfV3KNX0ekP

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-instances-1.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-instances
version:              1.0.1
visibility:           public
id:                   binary-instances-1.0.1-FMB5eUsuphx1qc34vFJFAh
key:                  binary-instances-1.0.1-FMB5eUsuphx1qc34vFJFAh
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  d01eed9c1cb335320dae09eedceb89dd
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Scientific
    Data.Binary.Instances.Tagged Data.Binary.Instances.Text
    Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/binary-instances-1.0.1
hs-libraries:         HSbinary-instances-1.0.1-FMB5eUsuphx1qc34vFJFAh
depends:
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t base-4.14.1.0 binary-0.8.8.0
    binary-orphans-1.0.1-68HHVldkOJABENToOq6OHH
    case-insensitive-1.2.1.0-7Aj4g2iZgZR4Q8sB4UJ8do
    hashable-1.3.0.0-JPCB4MmZaOcIaoM3ucdjgC
    scientific-0.3.6.2-Ip3ggXxxNwm3oywsJ3ZDCs
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2
    text-binary-0.2.1.1-Bl0n9PdHQ5w1N8gChIUmsJ
    time-compat-1.9.5-2N5Zkxwf4QyJ66BA7l6Ey9
    unordered-containers-0.2.13.0-2nDlvtn1IciJcNnZKP7xpJ
    vector-0.12.1.2-DniijS7i95iDT0VwtGN3m0
    vector-binary-instances-0.2.5.1-G8k3uxQzASCERV9pBb1q1i

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
